aboutsummaryrefslogtreecommitdiff
path: root/bbot/bootstrap-manifest.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2017-05-01 16:24:12 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2017-05-01 16:24:12 +0200
commit1b9d5cd435b800adad6432bca91cac189ad58823 (patch)
treec43a2b4c2c45b6ed5c2ef4e17cd573f2d10d992f /bbot/bootstrap-manifest.hxx
parent6cabe4d21b49ea149e6694c7290ff3e1fa9e08d2 (diff)
Use standard version in bootstrap manifest
Diffstat (limited to 'bbot/bootstrap-manifest.hxx')
-rw-r--r--bbot/bootstrap-manifest.hxx13
1 files changed, 7 insertions, 6 deletions
diff --git a/bbot/bootstrap-manifest.hxx b/bbot/bootstrap-manifest.hxx
index 9d583ad..69fb358 100644
--- a/bbot/bootstrap-manifest.hxx
+++ b/bbot/bootstrap-manifest.hxx
@@ -8,6 +8,7 @@
#include <map>
#include <butl/manifest-forward>
+#include <butl/standard-version>
#include <bbot/types.hxx>
#include <bbot/utility.hxx>
@@ -21,14 +22,14 @@ namespace bbot
{
public:
// Map of packages to their (numeric) versions that were used inside the
// bootstrapped machine. Used to make sure bbot agent/worker use the same
// versions. For example:
//
- // libbbot-version: 1010100 # 1.1.1
- // bbot-version: 1010200 # 1.1.2
+ // libbbot-version: 1.2.3
+ // bbot-version: 1.2.4-a.0.1234.de2f
//
- using versions_type = std::map<string, uint64_t>;
+ using versions_type = std::map<string, butl::standard_version>;
versions_type versions;
explicit
@@ -21,14 +22,14 @@ namespace bbot
{
public:
- // Map of packages to their (numeric) versions that were used inside the
- // bootstrapped machine. Used to make sure bbot agent/worker use the same
- // versions. For example:
+ // Map of packages to their (standard project) versions that were used
+ // inside the bootstrapped machine. Used to make sure bbot agent/worker
+ // use the same versions. For example:
//